@@ -271,6 +271,14 @@ def uninit():
     """Uninitializes the processor."""
     libxsltmod.xsltUninit()
 
+#
+# Functions from module xsltlocale
+#
+
+def freeLocales():
+    """Cleanup function for the locale support on shutdown"""
+    libxsltmod.xsltFreeLocales()
+
 #
 # Functions from module xsltutils
 #
